@@ -4,7 +4,15 @@ module RubyProf
   # Prints out the call graph based on CallInfo instances. This
   # is mainly for debugging purposes as it provides access into
   # into RubyProf's internals.
-
+  #
+  # To use the printer:
+  #
+  #   result = RubyProf.profile do
+  #     [code to profile]
+  #   end
+  #
+  #   printer = RubyProf::CallInfoPrinter.new(result)
+  #   printer.print(STDOUT)
   class CallInfoPrinter < AbstractPrinter
     TIME_WIDTH = 0
 
@@ -19,7 +27,7 @@ module RubyProf
     end
 
     def print_methods(thread)
-      visitor = CallInfoVisitor.new(thread.top_call_infos)
+      visitor = CallInfoVisitor.new(thread.root_methods)
 
       visitor.visit do |call_info, event|
         if event == :enter
@@ -31,11 +39,13 @@ module RubyProf
           @output << "wt:#{sprintf("%#{TIME_WIDTH}.2f", call_info.wait_time)}, "
           @output << "ct:#{sprintf("%#{TIME_WIDTH}.2f", call_info.children_time)}, "
           @output << "call:#{call_info.called}, "
-          @output << "rec:#{call_info.recursive?}"
           @output << ")"
           @output << "\n"
         end
       end
     end
+
+    def print_footer(thread)
+    end
   end
 end
